# Changelog

## 0.5.2 - 2013/11/22

Fix social media page sharing logic: everything stands in the `td_cms/partials/page_social.html` template. Feel free to add your killer plugin.

## 0.5.1 - 2013/11/15

Fix requirements in setup.py installation script

## 0.5 - 2013/11/11

First public stable release

## TODO

* Write the doc :)
